==> mauticGIT-Test-20251212_104643.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/98/9824bb67e2094b77053bae25b1a57c9e.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/LeadBundle/Segment/Decorator/BaseDecorator.php */
class __TwigTemplate_c0c5e056d90f6c3e73e1f5e35666035a extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

namespace Mautic\\LeadBundle\\Segment\\Decorator;

use Doctrine\\DBAL\\Query\\Expression\\CompositeExpression;
use Mautic\\LeadBundle\\Entity\\RegexTrait;
use Mautic\\LeadBundle\\Segment\\ContactSegmentFilterCrate;
use Mautic\\LeadBundle\\Segment\\ContactSegmentFilterOperator;
use Mautic\\LeadBundle\\Segment\\Query\\Filter\\BaseFilterQueryBuilder;

class BaseDecorator implements FilterDecoratorInterface
{
    use RegexTrait;

    public function __construct(
        protected ContactSegmentFilterOperator \$contactSegmentFilterOperator
    ) {
    }

    /**
     * @return string|null
     */
    public function getField(ContactSegmentFilterCrate \$contactSegmentFilterCrate)
    {
        return \$contactSegmentFilterCrate->getField();
    }

    public function getTable(ContactSegmentFilterCrate \$contactSegmentFilterCrate): string
    {
        if (\$contactSegmentFilterCrate->isContactType()) {
            return MAUTIC_TABLE_PREFIX.'leads';
        }

        if (\$contactSegmentFilterCrate->isCompanyType()) {
            return MAUTIC_TABLE_PREFIX.'companies';
        }

        return '';
    }

    /**
     * @return string
     */
    public function getOperator(ContactSegmentFilterCrate \$contactSegmentFilterCrate)
    {
        \$operator = \$this->contactSegmentFilterOperator->fixOperator(\$contactSegmentFilterCrate->getOperator());

        return match (\$operator) {
            'startsWith', 'endsWith', 'contains' => 'like',
            default => \$operator,
        };
    }

    public function getQueryType(ContactSegmentFilterCrate \$contactSegmentFilterCrate): string
    {
        return BaseFilterQueryBuilder::getServiceId();
    }

    /**
     * @param array|string \$argument
     *
     * @return array|string
     */
    public function getParameterHolder(ContactSegmentFilterCrate \$contactSegmentFilterCrate, \$argument)
    {
        if (is_array(\$argument)) {
            \$result = [];
            foreach (\$argument as \$arg) {
                \$result[] = \$this->getParameterHolder(\$contactSegmentFilterCrate, \$arg);
            }

            return \$result;
        }

        return ':'.\$argument;
    }

    /**
     * @return array|bool|float|string|null
     */
    public function getParameterValue(ContactSegmentFilterCrate \$contactSegmentFilterCrate): mixed
    {
        \$filter = \$contactSegmentFilterCrate->getFilter();

        if (\$contactSegmentFilterCrate->filterValueDoNotNeedAdjustment()) {
            return \$filter;
        }

        switch (\$contactSegmentFilterCrate->getOperator()) {
            case 'in':
            case '!in':
                return !is_array(\$filter) ? explode('|', \$filter) : \$filter;
            case 'like':
            case '!like':
                return !str_contains(\$filter, '%') ? '%'.\$filter.'%' : \$filter;
            case 'contains':
                return '%'.\$filter.'%';
            case 'startsWith':
                return \$filter.'%';
            case 'endsWith':
                return '%'.\$filter;
            case 'regexp':
            case '!regexp':
                return \$this->prepareRegex(\$filter);
            case 'multiselect':
            case '!multiselect':
                \$filter = (array) \$filter;

                foreach (\$filter as \$key => \$value) {
                    \$filter[\$key] = sprintf('(([|]|^)%s([|]|\$))', preg_quote(\$value, '/'));
                }

                return \$filter;
        }

        return \$filter;
    }

    public function getAggregateFunc(ContactSegmentFilterCrate \$contactSegmentFilterCrate): bool|string
    {
        return false;
    }

    /**
     * @return CompositeExpression|string|null
     */
    public function getWhere(ContactSegmentFilterCrate \$contactSegmentFilterCrate)
    {
        return null;
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/LeadBundle/Segment/Decorator/BaseDecorator.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/LeadBundle/Segment/Decorator/BaseDecorator.php", "/var/www/mautic-ktn/app/bundles/LeadBundle/Segment/Decorator/BaseDecorator.php");
    }
}

==> mauticGIT-Test-20260119_091040.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/98/9824bb67e2094b77053bae25b1a57c9e.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/LeadBundle/Segment/Decorator/BaseDecorator.php */
class __TwigTemplate_c0c5e056d90f6c3e73e1f5e35666035a extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

namespace Mautic\\LeadBundle\\Segment\\Decorator;

use Doctrine\\DBAL\\Query\\Expression\\CompositeExpression;
use Mautic\\LeadBundle\\Entity\\RegexTrait;
use Mautic\\LeadBundle\\Segment\\ContactSegmentFilterCrate;
use Mautic\\LeadBundle\\Segment\\ContactSegmentFilterOperator;
use Mautic\\LeadBundle\\Segment\\Query\\Filter\\BaseFilterQueryBuilder;

class BaseDecorator implements FilterDecoratorInterface
{
    use RegexTrait;

    public function __construct(
        protected ContactSegmentFilterOperator \$contactSegmentFilterOperator
    ) {
    }

    /**
     * @return string|null
     */
    public function getField(ContactSegmentFilterCrate \$contactSegmentFilterCrate)
    {
        return \$contactSegmentFilterCrate->getField();
    }

    public function getTable(ContactSegmentFilterCrate \$contactSegmentFilterCrate): string
    {
        if (\$contactSegmentFilterCrate->isContactType()) {
            return MAUTIC_TABLE_PREFIX.'leads';
        }

        if (\$contactSegmentFilterCrate->isCompanyType()) {
            return MAUTIC_TABLE_PREFIX.'companies';
        }

        return '';
    }

    /**
     * @return string
     */
    public function getOperator(ContactSegmentFilterCrate \$contactSegmentFilterCrate)
    {
        \$operator = \$this->contactSegmentFilterOperator->fixOperator(\$contactSegmentFilterCrate->getOperator());

        return match (\$operator) {
            'startsWith', 'endsWith', 'contains' => 'like',
            default => \$operator,
        };
    }

    public function getQueryType(ContactSegmentFilterCrate \$contactSegmentFilterCrate): string
    {
        return BaseFilterQueryBuilder::getServiceId();
    }

    /**
     * @param array|string \$argument
     *
     * @return array|string
     */
    public function getParameterHolder(ContactSegmentFilterCrate \$contactSegmentFilterCrate, \$argument)
    {
        if (is_array(\$argument)) {
            \$result = [];
            foreach (\$argument as \$arg) {
                \$result[] = \$this->getParameterHolder(\$contactSegmentFilterCrate, \$arg);
            }

            return \$result;
        }

        return ':'.\$argument;
    }

    /**
     * @return array|bool|float|string|null
     */
    public function getParameterValue(ContactSegmentFilterCrate \$contactSegmentFilterCrate): mixed
    {
        \$filter = \$contactSegmentFilterCrate->getFilter();

        if (\$contactSegmentFilterCrate->filterValueDoNotNeedAdjustment()) {
            return \$filter;
        }

        switch (\$contactSegmentFilterCrate->getOperator()) {
            case 'in':
            case '!in':
                return !is_array(\$filter) ? explode('|', \$filter) : \$filter;
            case 'like':
            case '!like':
                return !str_contains(\$filter, '%') ? '%'.\$filter.'%' : \$filter;
            case 'contains':
                return '%'.\$filter.'%';
            case 'startsWith':
                return \$filter.'%';
            case 'endsWith':
                return '%'.\$filter;
            case 'regexp':
            case '!regexp':
                return \$this->prepareRegex(\$filter);
            case 'multiselect':
            case '!multiselect':
                \$filter = (array) \$filter;

                foreach (\$filter as \$key => \$value) {
                    \$filter[\$key] = sprintf('(([|]|^)%s([|]|\$))', preg_quote(\$value, '/'));
                }

                return \$filter;
        }

        return \$filter;
    }

    public function getAggregateFunc(ContactSegmentFilterCrate \$contactSegmentFilterCrate): bool|string
    {
        return false;
    }

    /**
     * @return CompositeExpression|string|null
     */
    public function getWhere(ContactSegmentFilterCrate \$contactSegmentFilterCrate)
    {
        return null;
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/LeadBundle/Segment/Decorator/BaseDecorator.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/LeadBundle/Segment/Decorator/BaseDecorator.php", "/var/www/html/mauticGIT-Test/app/bundles/LeadBundle/Segment/Decorator/BaseDecorator.php");
    }
}
